@@ -4,6 +4,7 @@ import uuid
 from django.test import TestCase
 from django.db import models as dj_models
 
+from google.protobuf.any_pb2 import Any
 from google.protobuf.timestamp_pb2 import Timestamp
 from google.protobuf.descriptor import FieldDescriptor
 
@@ -74,7 +75,7 @@ class ProtoBufConvertingTest(TestCase):
                 main_item.m2m_field.order_by('id').values_list('id', flat=True),
                 main_item2.m2m_field.order_by('id').values_list('id', flat=True))
         )
-    
+
         main_item2.save()
         main_item2 = models.Main.objects.get()
         assert main_item.to_pb() == main_item2.to_pb()
@@ -127,6 +128,15 @@ class ProtoBufConvertingTest(TestCase):
                         third=pb_value[2]
                     ))
 
+        test_uuid = uuid.UUID('acf9d4c5-335c-4ad7-9e60-32e7306ea7c0')
+
+        def _test_uuid_to_pb(pb_obj, pb_field, dj_field_value):
+            # always set to test_uuid at test
+            setattr(pb_obj, pb_field.name, test_uuid.hex)
+
+        def _test_uuid_from_pb(instance, dj_field_name, pb_field, pb_value):
+            setattr(instance, dj_field_name, uuid.UUID(pb_value))
+
         # This is a relation type that's not ProtoBuf enabled
         class NativeRelation(dj_models.Model):
             first = dj_models.IntegerField()
@@ -138,11 +148,16 @@ class ProtoBufConvertingTest(TestCase):
             pb_model = models_pb2.Root
             pb_2_dj_fields = ['foreign_field']
             pb_2_dj_field_serializers = {
-                'foreign_field': (serializer, deserializer)
+                'foreign_field': (serializer, deserializer),
+                dj_models.UUIDField: (_test_uuid_to_pb, _test_uuid_from_pb),
             }
             foreign_field = dj_models.ForeignKey(NativeRelation, on_delete=dj_models.DO_NOTHING)
+            uuid_field = dj_models.UUIDField()
 
-        _in = Model(foreign_field=NativeRelation(first=123, second=456, third=789))
+        _in = Model(
+            foreign_field=NativeRelation(first=123, second=456, third=789),
+            uuid_field=uuid.uuid4(),
+        )
 
         out = Model().from_pb(_in.to_pb())
 
@@ -150,10 +165,17 @@ class ProtoBufConvertingTest(TestCase):
         assert out.foreign_field.second == 456
         assert out.foreign_field.third == 789
 
+        assert _in.uuid_field != test_uuid
+        assert out.uuid_field == test_uuid
+
 
     def test_auto_fields(self):
         timestamp = Timestamp()
         timestamp.FromDatetime(datetime.datetime.now())
+
+        _any = Any()
+        _any.Pack(timestamp)
+
         pb_object = models_pb2.Root(
             uint32_field=1234,
             uint64_field=123,
@@ -164,7 +186,7 @@ class ProtoBufConvertingTest(TestCase):
             bytes_field=b'123',
             bool_field=True,
             uuid_field=str(uuid.uuid4()),
-
+            any_field=_any,
             enum_field=1,
             timestamp_field=timestamp,
             repeated_uint32_field=[1, 2, 3],
@@ -200,6 +222,7 @@ class ProtoBufConvertingTest(TestCase):
         assert [o.data for o in dj_object_from_db.repeated_message_field] == [123, 456, 789]
         assert {k: o.data for k, o in dj_object_from_db.map_string_to_message_field.items()} == {'qwe': 123, 'asd': 456}
         assert dj_object_from_db.uint32_field_renamed == pb_object.uint32_field
+        assert dj_object_from_db.any_field == _any
         result = dj_object_from_db.to_pb()
         assert pb_object == result
 
@@ -223,68 +246,68 @@ class ProtoBufConvertingTest(TestCase):
         self.assertEqual(unlimited_main_proto.fk_field.num, relation_item.num,
                          msg="{}(src) != {}(target)".format(
                          unlimited_main_proto.fk_field.num, relation_item.num))
-        self.assertEqual(unlimited_main_proto.fk_field.deeper_relation.id, 
+        self.assertEqual(unlimited_main_proto.fk_field.deeper_relation.id,
                          deepter_relation_item.id,
                          msg="{}(src) != {}(target)".format(
-                         unlimited_main_proto.fk_field.deeper_relation.id, 
+                         unlimited_main_proto.fk_field.deeper_relation.id,
                          deepter_relation_item.id))
-        self.assertEqual(unlimited_main_proto.fk_field.deeper_relation.num, 
+        self.assertEqual(unlimited_main_proto.fk_field.deeper_relation.num,
                          deepter_relation_item.num,
                          msg="{}(src) != {}(target)".format(
-                         unlimited_main_proto.fk_field.deeper_relation.num, 
+                         unlimited_main_proto.fk_field.deeper_relation.num,
                          deepter_relation_item.num))
 
 
         # Verify no relation is converted when depth = 0.
         cap_0_main_proto = main_item.to_pb(depth=0)
         # proto3 does not support `hasField`, check value not equal instead.
-        self.assertNotEqual(cap_0_main_proto.fk_field.id, 
+        self.assertNotEqual(cap_0_main_proto.fk_field.id,
                             relation_item.id,
                             msg="{}(src) == {}(target)".format(
-                                cap_0_main_proto.fk_field.id, 
+                                cap_0_main_proto.fk_field.id,
                                 relation_item.id))
-        self.assertNotEqual(cap_0_main_proto.fk_field.num, 
+        self.assertNotEqual(cap_0_main_proto.fk_field.num,
                             relation_item.num,
                             msg="{}(src) == {}(target)".format(
-                                cap_0_main_proto.fk_field.num, 
+                                cap_0_main_proto.fk_field.num,
                                 relation_item.num))
         self.assertNotEqual(
-            cap_0_main_proto.fk_field.deeper_relation.id, 
+            cap_0_main_proto.fk_field.deeper_relation.id,
             deepter_relation_item.id,
             msg="{}(src) == {}(target)".format(
-                cap_0_main_proto.fk_field.deeper_relation.id, 
+                cap_0_main_proto.fk_field.deeper_relation.id,
                 deepter_relation_item.id))
         self.assertNotEqual(
-            cap_0_main_proto.fk_field.deeper_relation.num, 
+            cap_0_main_proto.fk_field.deeper_relation.num,
             deepter_relation_item.num,
             msg="{}(src) == {}(target)".format(
-                cap_0_main_proto.fk_field.deeper_relation.num, 
+                cap_0_main_proto.fk_field.deeper_relation.num,
                 deepter_relation_item.num))
 
         # Verify only 1 level relation is converted when depth = 1.
         cap_1_main_proto = main_item.to_pb(depth=1)
         # proto3 does not support `hasField`, check value not equal instead.
-        self.assertEqual(cap_1_main_proto.fk_field.id, 
+        self.assertEqual(cap_1_main_proto.fk_field.id,
                          relation_item.id,
                          msg="{}(src) != {}(target)".format(
-                            cap_1_main_proto.fk_field.id, 
+                            cap_1_main_proto.fk_field.id,
                             relation_item.id))
-        self.assertEqual(cap_1_main_proto.fk_field.num, 
+        self.assertEqual(cap_1_main_proto.fk_field.num,
                          relation_item.num,
                          msg="{}(src) != {}(target)".format(
-                            cap_1_main_proto.fk_field.num, 
+                            cap_1_main_proto.fk_field.num,
                             relation_item.num))
         self.assertNotEqual(
-            cap_1_main_proto.fk_field.deeper_relation.id, 
+            cap_1_main_proto.fk_field.deeper_relation.id,
             deepter_relation_item.id,
             msg="{}(src) == {}(target)".format(
-                cap_1_main_proto.fk_field.deeper_relation.id, 
+                cap_1_main_proto.fk_field.deeper_relation.id,
                 deepter_relation_item.id))
         self.assertNotEqual(
-            cap_1_main_proto.fk_field.deeper_relation.num, 
+            cap_1_main_proto.fk_field.deeper_relation.num,
             deepter_relation_item.num,
             msg="{}(src) == {}(target)".format(
-                cap_1_main_proto.fk_field.deeper_relation.num, 
+                cap_1_main_proto.fk_field.deeper_relation.num,
                 deepter_relation_item.num))
 
     def test_reverse_relation(self):
@@ -294,4 +317,4 @@ class ProtoBufConvertingTest(TestCase):
         relation_item2 = models.Relation.objects.create(
             num=2, deeper_relation=deeper_relation_item)
 
-        test_proto = deeper_relation_item.to_pb() 
\ No newline at end of file
+        test_proto = deeper_relation_item.to_pb()
